==> ejc-labor-impl-3.0.0-20221116.095757-17-sources.jar: com/ejianc/business/labor/bean/ProjectTeamEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目班组
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_project_team")
public class ProjectTeamEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="parent_code")
    private String parentCode;//父班组编码
    @TableField(value="parent_name")
    private String parentName;//父班组名称
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源标识（0自制、1公司班组）
    @TableField(value="source_org_team_id")
    private Long sourceOrgTeamId; // 来源公司班组ID
    @TableField(value="inner_code")
    private String innerCode; // innerCode
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 班组名称
    @TableField(value="leader_name")
    private String leaderName; // 班组长名称
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织id
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="is_leaf")
    private Boolean isLeaf; // 是否是叶子节点

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }



    public Boolean getIsLeaf() {
        return isLeaf;
    }

    public void setIsLeaf(Boolean leaf) {
        isLeaf = leaf;
    }

    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public Long getSourceOrgTeamId() {
        return sourceOrgTeamId;
    }

    public void setSourceOrgTeamId(Long sourceOrgTeamId) {
        this.sourceOrgTeamId = sourceOrgTeamId;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getLeaderName() {
        return leaderName;
    }

    public void setLeaderName(String leaderName) {
        this.leaderName = leaderName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-labor-impl-3.0.0-20221122.091116-47-sources.jar: com/ejianc/business/labor/bean/ProjectTeamEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目班组
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_project_team")
public class ProjectTeamEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="parent_code")
    private String parentCode;//父班组编码
    @TableField(value="parent_name")
    private String parentName;//父班组名称
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源标识（0自制、1公司班组）
    @TableField(value="source_org_team_id")
    private Long sourceOrgTeamId; // 来源公司班组ID
    @TableField(value="source_parent_id")
    private Long sourceParentId; // 来源公司班组 父ID
    @TableField(value="inner_code")
    private String innerCode; // innerCode
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 班组名称
    @TableField(value="leader_name")
    private String leaderName; // 班组长名称
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织id
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="is_leaf")
    private Boolean isLeaf; // 是否是叶子节点


    public Long getSourceParentId() {
        return sourceParentId;
    }

    public void setSourceParentId(Long sourceParentId) {
        this.sourceParentId = sourceParentId;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }



    public Boolean getIsLeaf() {
        return isLeaf;
    }

    public void setIsLeaf(Boolean leaf) {
        isLeaf = leaf;
    }

    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public Long getSourceOrgTeamId() {
        return sourceOrgTeamId;
    }

    public void setSourceOrgTeamId(Long sourceOrgTeamId) {
        this.sourceOrgTeamId = sourceOrgTeamId;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getLeaderName() {
        return leaderName;
    }

    public void setLeaderName(String leaderName) {
        this.leaderName = leaderName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
